==> haskell-hasql-transaction-0.5-42-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5
id: hasql-transaction-0.5-8md5EME2qR03Wh9pORfwTd
key: hasql-transaction-0.5-8md5EME2qR03Wh9pORfwTd
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: 08d7bee1404798cc307c3c4c63a5beb6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hasql-transaction-0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/hasql-transaction-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/hasql-transaction-0.5
hs-libraries: HShasql-transaction-0.5-8md5EME2qR03Wh9pORfwTd
depends:
    base-4.9.1.0 base-prelude-1.2.0.1-HJh3WMXaeu8jTCoycvBYB
    bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-Ov0yHD3PiGEX50CZo7CAm
    contravariant-1.4-8XNcYhxZMQPHL9Afkgrfdc
    contravariant-extras-0.3.3.1-DNJYVar52LsHQQRLPytqgP
    hasql-0.19.18-Ln6fo3vnTVg4TyOEWhDbCu
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.5-50-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5
id: hasql-transaction-0.5-5FG6hYNYwfgJ8gI0VJYAmM
key: hasql-transaction-0.5-5FG6hYNYwfgJ8gI0VJYAmM
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: 07fda13978fd08a15304332f4e85cb12
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hasql-transaction-0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/hasql-transaction-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/hasql-transaction-0.5
hs-libraries: HShasql-transaction-0.5-5FG6hYNYwfgJ8gI0VJYAmM
depends:
    base-4.9.1.0 base-prelude-1.2.0.1-HJh3WMXaeu8jTCoycvBYB
    bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-Ov0yHD3PiGEX50CZo7CAm
    contravariant-1.4-8XNcYhxZMQPHL9Afkgrfdc
    contravariant-extras-0.3.3.1-DNJYVar52LsHQQRLPytqgP
    hasql-0.19.18.1-LjcK6lnh8EO8Lxbu2n4zDJ
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
